OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Запись в каталог \"config\" невозможна!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Обычно это можно исправить предоставив веб-серверу права на запись в каталоге конфигурации",
    "See %s" : "Смотрите %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Обычно это можно исправить %sпредоставив веб-серверу права на запись в каталоге конфигурации%s.",
    "Sample configuration detected" : "Обнаружена конфигурация из примера",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Была обнаружена конфигурация из примера. Такая конфигурация не поддерживается и может повредить вашей системе. Прочтите документацию перед внесением изменений в файл config.php",
    "PHP %s or higher is required." : "Требуется PHP %s или новее",
    "PHP with a version lower than %s is required." : "Требуется версия PHP ниже чем %s.",
    "%sbit or higher PHP required." : "Требуется PHP с разрядностью %s бит или более.",
    "Following databases are supported: %s" : "Поддерживаются следующие СУБД: %s",
    "The command line tool %s could not be found" : "Утилита командной строки %s не найдена",
    "The library %s is not available." : "Библиотека %s недоступна.",
    "Library %s with a version higher than %s is required - available version %s." : "Требуется библиотека %s версии не меньше %s, установлена версия %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Требуется библиотека %s версии не выше %s, установлена версия %s.",
    "Following platforms are supported: %s" : "Поддерживаются следующие платформы: %s",
    "ownCloud %s or higher is required." : "Требуется ownCloud %s или выше.",
    "ownCloud %s or lower is required." : "Требуется ownCloud версии %s или ниже.",
    "Unknown filetype" : "Неизвестный тип файла",
    "Invalid image" : "Изображение повреждено",
    "Avatar image is not square" : "Изображение аватара не является квадратным",
    "today" : "сегодня",
    "yesterday" : "вчера",
    "_%n day ago_::_%n days ago_" : ["%n день назад","%n дня назад","%n дней назад","%n дней назад"],
    "last month" : "в прошлом месяце",
    "_%n month ago_::_%n months ago_" : ["%n месяц назад","%n месяца назад","%n месяцев назад","%n месяцев назад"],
    "last year" : "в прошлом году",
    "_%n year ago_::_%n years ago_" : ["%n год назад","%n года назад","%n лет назад","%n лет назад"],
    "_%n hour ago_::_%n hours ago_" : ["%n час назад","%n часа назад","%n часов назад","%n часов назад"],
    "_%n minute ago_::_%n minutes ago_" : ["%n минута назад","%n минуты назад","%n минут назад","%n минут назад"],
    "seconds ago" : "несколько секунд назад",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль с ID %s не существует. Пожалуйста включите его в настройках приложений или обратитесь к администратору.",
    "Builtin" : "Встроенный",
    "None" : "Пусто",
    "Username and password" : "Имя пользователя и пароль",
    "Username" : "Имя пользователя",
    "Password" : "Пароль",
    "Log-in credentials, save in session" : "Учетные данные, хранить в сессии",
    "Empty filename is not allowed" : "Пустое имя файла не допускается",
    "Dot files are not allowed" : "Файлы начинающиеся с точки не допускаются",
    "4-byte characters are not supported in file names" : "4-х байтовые символы в имени файлов не допускаются",
    "File name is a reserved word" : "Имя файла является зарезервированным словом",
    "File name contains at least one invalid character" : "Имя файла содержит по крайней мере один некорректный символ",
    "File name is too long" : "Имя файла слишком длинное.",
    "__language_name__" : "Русский",
    "App directory already exists" : "Каталог приложения уже существует",
    "Can't create app folder. Please fix permissions. %s" : "Не удалось создать каталог приложения. Исправьте права доступа. %s",
    "Archive does not contain a directory named %s" : "Архив не содержит папки с именем %s",
    "No source specified when installing app" : "Не указан источник при установке приложения",
    "No href specified when installing app from http" : "Не указан атрибут href при установке приложения через http",
    "No path specified when installing app from local file" : "Не указан путь при установке приложения из локального файла",
    "Archives of type %s are not supported" : "Архивы %s не поддерживаются",
    "Failed to open archive when installing app" : "Ошибка открытия архива при установке приложения",
    "App does not provide an info.xml file" : "Приложение не имеет файла info.xml",
    "App cannot be installed because appinfo file cannot be read." : "Приложение не может быть установлено, так как файл с информацией о приложении не может быть прочтен.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Подпись не может быть проверена. Пожалуйста, свяжитесь с разработчиком приложения и проверьте свою страницу администратора.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Приложение невозможно установить. Не совместимо с текущей версией ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Приложение невозможно установить. Оно содержит параметр <shipped>true</shipped> который не допустим для приложений, не входящих в поставку.",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Приложение невозможно установить. Версия в файле info.xml не совпадает с версией заявленной в магазине приложений",
    "No license key available." : "Лицензионный ключе недоступен.",
    "Invalid license key!" : "Неправильный лицензионный ключ!",
    "Please contact your administrator or %s for a new license key." : "Пожалуйста, свяжитесь с вашим администратором, или %s, чтобы получить новый лицензионный ключ.",
    "Your Enterprise license key has expired." : "Ваш лицензионный ключ для Enterprise устарел.",
    "Enterprise features have been disabled." : "Возможности Enterprise были отключены.",
    "Evaluation - expires in %d days." : "Пробный период истекает через %d дней.",
    "Your Enterprise license key is about to expire (days remaining: %d)." : "Ваш лицензионный ключ для Enterprise скоро устареет (осталось дней: %d).",
    "The registered enterprise license key expires in %d days" : "Зарегистрированный лицензионный ключ для Enterprise устареет через %d days",
    "New Design" : "Новый дизайн",
    "Apps" : "Приложения",
    "General" : "Основные",
    "Storage" : "Хранилище",
    "Security" : "Безопасность",
    "User Authentication" : "Аутентификация пользователя",
    "Encryption" : "Шифрование",
    "Workflows & Tags" : "Рабочие процессы и метки",
    "Sharing" : "Общий доступ",
    "Search" : "Найти",
    "Help & Tips" : "Помощь и советы",
    "Additional" : "Дополнительно",
    "%s enter the database username and name." : "%s укажите имя пользователя и название для базы данных.",
    "%s enter the database username." : "%s введите имя пользователя базы данных.",
    "%s enter the database name." : "%s введите имя базы данных.",
    "%s enter the database name or connection string." : "1%s введите название базы данных или строку подключения",
    "Oracle connection could not be established" : "Соединение с Oracle не может быть установлено",
    "Oracle username and/or password not valid" : "Неверное имя пользователя и/или пароль Oracle",
    "DB Error: \"%s\"" : "Ошибка БД: \"%s\"",
    "Offending command was: \"%s\"" : "Вызываемая команда была: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Вы должны войти или в существующий аккаунт или под администратором.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Вызываемая команда была: \"%s\", имя: %s, пароль: %s",
    "PostgreSQL username and/or password not valid" : "Неверное имя пользователя и/или пароль PostgreSQL",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s не поддерживается и %s не будет работать правильно на этой платформе. Используйте на свой страх и риск! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Пожалуйста, удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
    "Set an admin username." : "Задать имя пользователя для администратора.",
    "Set an admin password." : "Задать пароль для admin.",
    "Can't create or write into the data directory %s" : "Невозможно создать или записать в каталог данных %s",
    "Can't create or write into the apps-external directory %s" : "Не удалось создать или записать в каталоге внешних приложений %s",
    "Can't update %s - it is a directory" : "Невозможно обновить %s - это каталог",
    "Can't update %s" : "Не получается обновить %s",
    "Invalid Federated Cloud ID" : "Неверный ID в объединении облачных хранилищ.",
    "Internal mail notification for shared files is not allowed" : "Внутреннее уведомление почтой для совместного доступа к файлам не разрешено",
    "%s shared »%s« with you" : "%s поделился »%s« с вами",
    "Public link mail notification is not allowed" : "Почтовые уведомления для общедоступных ссылок не разрешены",
    "%s via %s" : "%s через %s",
    "Sharing %s failed, because the backend does not allow shares from type %d" : "Не удалось предоставить общий доступ к %s,  так как бэкенд не разрешает общий доступ для типа %d",
    "Sharing %s failed, because the file does not exist" : "Не удалось поделиться %s, файл не существует",
    "You are not allowed to share %s" : "Вам не разрешено делиться %s",
    "Sharing %s failed, because you can not share with yourself" : "Не удалось поделиться %s. Вы не можете поделиться с самим собой.",
    "Sharing %s failed, because the user %s does not exist" : "Не удалось поделиться %s, пользователь %s не существует.",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Не удалось поделиться %s, так как пользователь %s не состоит в какой-либо группе, в которой состоит %s",
    "Sharing %s failed, because this item is already shared with %s" : "Не удалось поделиться %s, пользователь %s уже имеет доступ к этому элементу",
    "Sharing %s failed, because this item is already shared with user %s" : "Не удалось поделиться %s, так как элемент находится в общем доступе у %s",
    "Sharing %s failed, because the group %s does not exist" : "Не удалось поделиться %s, группа %s не существует",
    "Sharing %s failed, because %s is not a member of the group %s" : "Не удалось поделиться %s, пользователь %s не является членом группы %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Вам нужно задать пароль для создания публичной ссылки. Разрешены только защищённые ссылки",
    "Sharing %s failed, because sharing with links is not allowed" : "Не удалось поделиться %s, открытие доступа по ссылке запрещено",
    "Not allowed to create a federated share with the same user" : "Не допускается создание федеративного общего ресурса с тем же пользователем",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "Не удалось предоставить доступ к %s, не удалось найти %s, проверьте написание и доступность сервера.",
    "Share type %s is not valid for %s" : "Тип общего доступа %s недопустим для %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Не удалось настроить права доступа для %s, указанные права доступа превышают предоставленные для %s",
    "Setting permissions for %s failed, because the item was not found" : "Не удалось настроить права доступа для %s, элемент не найден.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Невозможно установить дату истечения. Общие ресурсы не могут устареть позже %s с момента их публикации.",
    "Cannot set expiration date. Expiration date is in the past" : "Невозможно установить дату окончания. Дата окончания в прошлом.",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Не могу очистить дату истечения срока действия. Общие ресурсы должны иметь срок годности.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бэкенд общего доступа %s должен реализовывать интерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Бэкенд общего доступа %s не найден",
    "Sharing backend for %s not found" : "Бэкенд общего доступа для %s не найден",
    "Sharing failed, because the user %s is the original sharer" : "Не удалось поделиться, потому что пользователь %s владелец этого элемента",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Не удалось поделиться %s, права превышают предоставленные права доступа %s",
    "Sharing %s failed, because resharing is not allowed" : "Не удалось поделиться %s, повторное открытие доступа запрещено",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Не удалось поделиться %s, бэкенд общего доступа не нашел путь до %s",
    "Sharing %s failed, because the file could not be found in the file cache" : "Не удалось поделиться %s, элемент не найден в файловом кеше.",
    "Invalid permissions" : "Недопустимые права",
    "Cannot remove all permissions" : "Не могу удалить все права",
    "Cannot set the requested share permissions for %s" : "Не удалось получить запрошенные права доступа для %s",
    "Cannot set the requested share attributes for %s" : "Не удалось установить запрошенные атрибуты общего доступа для %s",
    "Expiration date is in the past" : "Дата окончания срока действия уже прошла",
    "Cannot set expiration date more than %s days in the future" : "Невозможно установить дату окончания срока действия более %s дней",
    "Could not find category \"%s\"" : "Категория \"%s\"  не найдена",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"+_.@-'\"" : "В имени пользователя допустимы только следующие символы: «a—z», «A—Z», «0—9», и «+_.@-'»",
    "A valid username must be provided" : "Укажите допустимое имя пользователя",
    "Username contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробел в начале или в конце",
    "The username must be at least 3 characters long" : "Имя пользователя должно быть не менее 3 символов в длину",
    "The username can not be longer than 64 characters" : "Имя пользователя не может быть длиннее 64 символов",
    "A valid password must be provided" : "Укажите допустимый пароль",
    "The username is already being used" : "Имя пользователя уже используется",
    "Login canceled by app" : "Вход отменен приложением",
    "User disabled" : "Пользователь отключен",
    "Settings" : "Настройки",
    "Users" : "Пользователи",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Приложение \"%s\" не может быть установлено, так как следующие зависимости не выполнены: %s",
    "A safe home for all your data" : "Безопасный дом для всех ваших данных",
    "Imprint" : "Штамп",
    "Privacy Policy" : "Политика конфиденциальности",
    "File is currently busy, please try again later" : "Файл в данный момент используется, повторите попытку позже.",
    "Access to this resource or one of its sub-items has been denied." : "Запрещён доступ к этому ресурсу или к одному из его подчинённых элементов.",
    "File cannot be downloaded" : "Скачать файл не удалось",
    "Application is not enabled" : "Приложение не разрешено",
    "Authentication error" : "Ошибка аутентификации",
    "Token expired. Please reload page." : "Токен просрочен. Перезагрузите страницу.",
    "Unknown user" : "Неизвестный пользователь",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не установлены драйвера баз данных (sqlite, mysql или postgresql)",
    "Cannot write into \"config\" directory" : "Запись в каталог \"config\" невозможна",
    "Cannot create \"data\" directory" : "Не могу создать каталог \"data\"",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Обычно это можно исправить <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">предоставив веб-серверу права на запись в корневом каталоге</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Обычно это можно исправить, %sпредоставив веб-серверу права на запись в корневой каталог%s.",
    "Setting locale to %s failed" : "Установка локали %s не удалась",
    "Please install one of these locales on your system and restart your webserver." : "Установите один из этих языковых пакетов на вашу систему и перезапустите веб-сервер.",
    "Please ask your server administrator to install the module." : "Пожалуйста, попростите администратора сервера установить модуль.",
    "PHP module %s not installed." : "Не установлен PHP-модуль %s.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не установлен в \"%s\".",
    "Adjusting this setting in php.ini will make ownCloud run again" : "Установка этого параметра в php.ini позволит запуститься ownCloud снова.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload установлен в \"%s\", при этом требуется \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Чтобы исправить эту проблему установите параметр <code>mbstring.func_overload</code> в значение <code>0</code> в php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Требуется как минимум libxml2 версии 2.7.0. На данный момент установлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Для исправления этой ошибки обновите версию libxml2 и перезапустите ваш веб-сервер.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "По всей видимост, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модули PHP были установлены, но они все еще перечислены как недостающие?",
    "Please ask your server administrator to restart the web server." : "Пожалуйста, попросите вашего администратора перезапустить веб-сервер.",
    "PostgreSQL >= 9 required" : "Требуется PostgreSQL >= 9",
    "Please upgrade your database version" : "Пожалуйста обновите версию базы данных",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Измените права доступа на 0770, чтобы другие пользователи не могли получить список файлов этого каталога.",
    "Your Data directory is readable by other users" : "Ваш каталог данных доступен на чтение для других пользователей",
    "Your Data directory must be an absolute path" : "Путь к каталогу данных должен быть абсолютным",
    "Check the value of \"datadirectory\" in your configuration" : "Проверьте значение \"datadirectory\" в настройках.",
    "Your Data directory  is invalid" : "Ваш каталог данных неверен",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Убедитесь, что файл \".ocdata\" присутствует в корне каталога данных.",
    "User unknown" : "Пользователь неизвестен",
    "Could not obtain lock type %d on \"%s\"." : "Не удалось получить блокировку типа %d для \"%s\"",
    "Storage unauthorized. %s" : "Хранилище неавторизовано. %s",
    "Storage incomplete configuration. %s" : "Неполная конфигурация хранилища.  %s",
    "Storage connection error. %s" : "Ошибка подключения к хранилищу. %s",
    "Storage is temporarily not available" : "Хранилище временно не доступно",
    "Storage connection timeout. %s" : "Истекло время ожидания подключения к хранилищу. %s",
    "\"%s\" is locked" : "«%s» заблокировано"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
